@@ -1,4 +1,6 @@
-from typing import Optional, List
+from __future__ import annotations
+
+from typing import Optional, List, Dict
 
 from typing_extensions import Self
 
@@ -8,8 +10,9 @@ from conductor.client.workflow.task.task_type import TaskType
 
 class LlmTextComplete(TaskInterface):
     def __init__(self, task_ref_name: str, llm_provider: str, model: str, prompt_name: str,
-                 stop_words: Optional[List[str]] = [], max_tokens: Optional[int] = 100,
-                 temperature: int = 0, top_p: int = 1, task_name: str = None) -> Self:
+                 stop_words: Optional[List[str]] = None, max_tokens: Optional[int] = 100,
+                 temperature: int = 0, top_p: int = 1, task_name: Optional[str] = None) -> Self:
+        stop_words = stop_words or []
         optional_input_params = {}
 
         if stop_words:
@@ -19,7 +22,7 @@ class LlmTextComplete(TaskInterface):
             optional_input_params.update({"maxTokens": max_tokens})
 
         if not task_name:
-            task_name = 'llm_text_complete'
+            task_name = "llm_text_complete"
 
         input_params = {
             "llmProvider": llm_provider,
@@ -38,12 +41,12 @@ class LlmTextComplete(TaskInterface):
             task_type=TaskType.LLM_TEXT_COMPLETE,
             input_parameters=input_params
         )
-        self.input_parameters['promptVariables'] = {}
+        self.input_parameters["promptVariables"] = {}
 
-    def prompt_variables(self, variables: dict[str, object]) -> Self:
-        self.input_parameters['promptVariables'].update(variables)
+    def prompt_variables(self, variables: Dict[str, object]) -> Self:
+        self.input_parameters["promptVariables"].update(variables)
         return self
 
     def prompt_variable(self, variable: str, value: object) -> Self:
-        self.input_parameters['promptVariables'][variable] = value
+        self.input_parameters["promptVariables"][variable] = value
         return self
